@@ -46,7 +46,7 @@ class Logging:
     NOTSET = NOTSET
 
     def __init__(self, name: str = __name__, level: logging.INFO = INFO,
-                 file: str = None, encoding: str = 'utf-8',
+                 file: str = None, encoding: str = 'utf-8', filemode: str = 'a',
                  log_stream: LogStream = False, timestamp: bool = True, **kwargs):
 
         self.logging = logging.getLogger(name)
@@ -74,7 +74,8 @@ class Logging:
         # self.log_format = '%(levelname)s\t%(message)s\t%(name)s'
 
         if file:
-            logging.basicConfig(filename=file, encoding=encoding, level=level, format=self.log_format, **kwargs)
+            logging.basicConfig(filename=file, encoding=encoding, filemode=filemode, level=level,
+                                format=self.log_format, **kwargs)
         else:
             logging.basicConfig(level=level, format=self.log_format, **kwargs)
 
